"""
Genetic Programming for Quant

Author: UePG

References:
[1] https://gplearn.readthedocs.io/en/stable/
[2] J. Koza, "Genetic Programming", 1992.
"""

__version__ = "0.1.6"

__all__ = ["Function", "Fitness", "Backtester", "SymbolicRegressor"]
